# -*- coding: utf-8 -*- #
# Copyright 2026 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Utilities for Cloud FTP long-running operations."""

from googlecloudsdk.api_lib.storage import ftp
from googlecloudsdk.api_lib.util import waiter
from googlecloudsdk.core import resources


def GetOperationRef(operation_name):
  """Converts an operation resource name to a Resource ref."""
  return resources.REGISTRY.ParseRelativeName(
      operation_name, collection='ftp.projects.locations.operations'
  )


def WaitForOperation(
    operation_ref, message, result_service=None, max_wait_ms=3600000
):
  """Waits for a long-running operation to complete.

  Args:
    operation_ref: a Resource created by GetOperationRef describing the
      operation.
    message: the message to display to the user while waiting.
    result_service: apitools service for retrieving resulting resource. If None,
      assumes operation creates no resource (e.g. Delete).
    max_wait_ms: max wait in milliseconds.

  Returns:
    Resulting resource or None.
  """
  client = ftp.FtpClient()
  if result_service:
    poller = waiter.CloudOperationPoller(
        result_service, client.operations_service
    )
  else:
    poller = waiter.CloudOperationPollerNoResources(client.operations_service)

  return waiter.WaitFor(poller, operation_ref, message, max_wait_ms=max_wait_ms)



# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Utilities for defining CRM Tag arguments on a parser."""

import argparse

from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope import base


def AddShortNameArgToParser(parser):
  """Adds positional argument to parser.

  Args:
    parser: ArgumentInterceptor, an argparse parser.
  """
  parser.add_argument(
      "short_name",
      metavar="SHORT_NAME",
      help=(
          "User specified, friendly name of the TagKey or TagValue. The field"
          " must be 1-63 characters, beginning and ending with an "
          "alphanumeric character ([a-z0-9A-Z]) with dashes (-), "
          "underscores ( _ ), dots (.), and alphanumerics between. "
      ),
  )


def AddParentArgToParser(parser, required=True, message=""):
  """Adds argument for the TagKey or TagValue's parent to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
    required: Boolean, to enforce --parent as a required flag.
    message: String, replacement help text for flag.
  """
  parser.add_argument(
      "--parent",
      metavar="PARENT",
      required=required,
      help=message if message else ("Parent of the resource."),
  )


def AddDescriptionArgToParser(parser):
  """Adds argument for the TagKey's or TagValue's description to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--description",
      metavar="DESCRIPTION",
      help=(
          "User-assigned description of the TagKey or TagValue. "
          "Must not exceed 256 characters."
      ),
  )


def AddAllowedValuesRegexArgToParser(parser: argparse.ArgumentParser) -> None:
  """Adds argument for the Regex of allowed TagValues under a TagKey.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--allowed-values-regex",
      metavar="ALLOWED_VALUES_REGEX",
      type=str,
      help=(
          "User-assigned regex of allowed short names of TagValues under a"
          " TagKey."
      ),
  )


def AddPurposeArgToParser(parser):
  """Adds argument for the TagKey's purpose to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--purpose",
      metavar="PURPOSE",
      choices=["GCE_FIREWALL", "DATA_GOVERNANCE"],
      help=(
          "Purpose specifier of the TagKey that can only be set on creation. "
          "Specifying this field adds additional validation from the policy "
          "system that corresponds to the purpose."
      ),
  )


def AddPurposeDataArgToParser(parser):
  """Adds argument for the TagKey's purpose data to the parser.

  Args:
     parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--purpose-data",
      type=arg_parsers.ArgDict(
          spec={"network": str, "organization": str},
          max_length=1,
      ),
      help=(
          "Purpose data of the TagKey that can only be set on creation. "
          "This data is validated by the policy system that corresponds"
          " to the purpose."
      ),
  )


def AddAsyncArgToParser(parser):
  """Adds async flag to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  base.ASYNC_FLAG.AddToParser(parser)


def AddResourceNameArgToParser(parser):
  """Adds resource name argument for the namespaced name or resource name to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "RESOURCE_NAME",
      metavar="RESOURCE_NAME",
      help=(
          "Resource name or namespaced name. The resource name should "
          "be in the form {resource_type}/{numeric_id}. The namespaced name "
          "should be in the form {org_id}/{short_name} where short_name "
          "must be 1-63 characters, beginning and ending with an "
          "alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores "
          "( _ ), dots (.), and alphanumerics between."
      ),
  )


def AddForceArgToParser(parser):
  """Adds force argument  to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--force", action="store_true", help="Force argument to bypass checks."
  )


def AddPolicyFileArgToParser(parser):
  """Adds argument for the local Policy file to set.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "POLICY_FILE",
      metavar="POLICY_FILE",
      help=(
          "Path to a local JSON or YAML formatted file containing a valid "
          "policy. The output of the `get-iam-policy` command is a valid "
          "file, as is any JSON or YAML file conforming to the structure of "
          "a [Policy](https://cloud.google.com/iam/reference/rest/v1/Policy)."
      ),
  )


def AddTagValueArgToParser(parser):
  """Adds the TagValue argument to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--tag-value",
      metavar="TAG_VALUE",
      required=True,
      help=(
          "Tag value name or namespaced name. The name should "
          "be in the form tagValues/{numeric_id}. The namespaced name "
          "should be in the form {org_id}/{tag_key_short_name}/{short_name} "
          "where short_name must be 1-63 characters, beginning and ending "
          "with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), "
          "underscores (_), dots (.), and alphanumerics between."
      ),
  )


def AddLocationArgToParser(parser, message):
  """Adds argument for the location.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
    message: String, help text for flag.
  """
  parser.add_argument(
      "--location", metavar="LOCATION", required=False, help=message
  )


def AddEffectiveArgToParser(parser, message):
  """Adds argument for the effective option.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
    message: String, help text for flag.
  """
  parser.add_argument(
      "--effective", action="store_true", required=False, help=message
  )


def UpdateTagGroup(parser):
  """Adds flags for the specifying tags to update for a resource."""
  group = parser.add_group(
      mutex=True, help="Tags to update for a resource.", required=True
  )
  subgroup = group.add_group(
      mutex=False, help="Tags to add/remove for a resource."
  )
  group.add_argument(
      "--clear-tags",
      action="store_true",
      required=False,
      help="Clear all tags on the resource.",
  )
  group.add_argument(
      "--replace-tags",
      type=arg_parsers.ArgObject(key_type=str, value_type=str),
      required=False,
      metavar="REPLACE_TAGS",
      action=arg_parsers.UpdateAction,
      help=(
          "Replace all existing tags on the resource with the specified"
          " key-value pairs."
      ),
  )
  subgroup.add_argument(
      "--remove-tags",
      type=arg_parsers.ArgList(min_length=1),
      metavar="REMOVE_TAGS",
      required=False,
      help="Remove the specified tags from the resource.",
  )
  subgroup.add_argument(
      "--update-tags",
      metavar="UPDATE_TAGS",
      required=False,
      type=arg_parsers.ArgObject(key_type=str, value_type=str),
      action=arg_parsers.UpdateAction,
      help="Add/update tags to the resource.",
  )


def AddUpdateResourceNameArgToParser(parser, required=True, message=""):
  """Adds argument for the UpdateTagBindings resource name to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
    required: Boolean, to enforce --parent as a required flag.
    message: String, replacement help text for flag.
  """
  parser.add_argument(
      "--resource-name",
      metavar="RESOURCE_NAME",
      required=required,
      help=message if message else ("Name of the resource."),
  )


def AddSemanticsArgToParser(parser: argparse.ArgumentParser) -> None:
  """Adds argument for TagKey's or TagValue's semantics to the parser.

  Args:
    parser: ArgumentInterceptor, An argparse parser.
  """
  parser.add_argument(
      "--semantics",
      metavar="SEMANTICS",
      hidden=True,
      help=(
          "Semantics identifier for the TagKey or TagValue. Must be from the"
          " list of predefined semantics."
      ),
  )


def AddSemanticsMutexGroupArgs(parser: argparse.ArgumentParser) -> None:
  """Adds mutually exclusive args for adding/removing semantics.

  Args:
    parser: ArgumentInterceptor, an argparse parser.
  """
  mutex_group = parser.add_group(mutex=True, hidden=True)
  mutex_group.add_argument(
      "--add-semantics",
      metavar="SEMANTICS",
      help="Semantics identifier to add to the TagKey or TagValue.",
  )
  mutex_group.add_argument(
      "--remove-semantics",
      action="store_true",
      help="Remove the semantics identifier from the TagKey or TagValue.",
  )




"""Generated client library for transferappliance version v1alpha1."""
# NOTE: This file is autogenerated and should not be edited by hand.

from apitools.base.py import base_api
from googlecloudsdk.generated_clients.apis.transferappliance.v1alpha1 import transferappliance_v1alpha1_messages as messages


class TransferapplianceV1alpha1(base_api.BaseApiClient):
  """Generated client library for service transferappliance version v1alpha1."""

  MESSAGES_MODULE = messages
  BASE_URL = 'https://transferappliance.googleapis.com/'
  MTLS_BASE_URL = 'https://transferappliance.mtls.googleapis.com/'

  _PACKAGE = 'transferappliance'
  _SCOPES = ['https://www.googleapis.com/auth/cloud-platform']
  _VERSION = 'v1alpha1'
  _CLIENT_ID = 'CLIENT_ID'
  _CLIENT_SECRET = 'CLIENT_SECRET'
  _USER_AGENT = 'google-cloud-sdk'
  _CLIENT_CLASS_NAME = 'TransferapplianceV1alpha1'
  _URL_VERSION = 'v1alpha1'
  _API_KEY = None

  def __init__(self, url='', credentials=None,
               get_credentials=True, http=None, model=None,
               log_request=False, log_response=False,
               credentials_args=None, default_global_params=None,
               additional_http_headers=None, response_encoding=None):
    """Create a new transferappliance handle."""
    url = url or self.BASE_URL
    super(TransferapplianceV1alpha1, self).__init__(
        url, credentials=credentials,
        get_credentials=get_credentials, http=http, model=model,
        log_request=log_request, log_response=log_response,
        credentials_args=credentials_args,
        default_global_params=default_global_params,
        additional_http_headers=additional_http_headers,
        response_encoding=response_encoding)
    self.projects_locations_appliances_credentials = self.ProjectsLocationsAppliancesCredentialsService(self)
    self.projects_locations_appliances = self.ProjectsLocationsAppliancesService(self)
    self.projects_locations_operations = self.ProjectsLocationsOperationsService(self)
    self.projects_locations_orders = self.ProjectsLocationsOrdersService(self)
    self.projects_locations_savedAddresses = self.ProjectsLocationsSavedAddressesService(self)
    self.projects_locations = self.ProjectsLocationsService(self)
    self.projects = self.ProjectsService(self)

  class ProjectsLocationsAppliancesCredentialsService(base_api.BaseApiService):
    """Service class for the projects_locations_appliances_credentials resource."""

    _NAME = 'projects_locations_appliances_credentials'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsAppliancesCredentialsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets Credentials of the appliance.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesCredentialsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Credential) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances/{appliancesId}/credentials/{credentialsId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.appliances.credentials.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsAppliancesCredentialsGetRequest',
        response_type_name='Credential',
        supports_download=False,
    )

  class ProjectsLocationsAppliancesService(base_api.BaseApiService):
    """Service class for the projects_locations_appliances resource."""

    _NAME = 'projects_locations_appliances'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsAppliancesService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new Appliance in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances',
        http_method='POST',
        method_id='transferappliance.projects.locations.appliances.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['applianceId', 'requestId', 'validateOnly'],
        relative_path='v1alpha1/{+parent}/appliances',
        request_field='appliance',
        request_type_name='TransferapplianceProjectsLocationsAppliancesCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes an Appliance.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances/{appliancesId}',
        http_method='DELETE',
        method_id='transferappliance.projects.locations.appliances.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['etag', 'requestId', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsAppliancesDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Export(self, request, global_params=None):
      r"""Gets user data by its resource name.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesExportRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ExportApplianceUserDataResponse) The response message.
      """
      config = self.GetMethodConfig('Export')
      return self._RunMethod(
          config, request, global_params=global_params)

    Export.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances/{appliancesId}:export',
        http_method='GET',
        method_id='transferappliance.projects.locations.appliances.export',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}:export',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsAppliancesExportRequest',
        response_type_name='ExportApplianceUserDataResponse',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets an Appliance resource by its resource name.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Appliance) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances/{appliancesId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.appliances.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsAppliancesGetRequest',
        response_type_name='Appliance',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists Appliances in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListAppliancesResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances',
        http_method='GET',
        method_id='transferappliance.projects.locations.appliances.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1alpha1/{+parent}/appliances',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsAppliancesListRequest',
        response_type_name='ListAppliancesResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates Appliance resource parameters.

      Args:
        request: (TransferapplianceProjectsLocationsAppliancesPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/appliances/{appliancesId}',
        http_method='PATCH',
        method_id='transferappliance.projects.locations.appliances.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['allowMissing', 'requestId', 'updateMask', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='appliance',
        request_type_name='TransferapplianceProjectsLocationsAppliancesPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

  class ProjectsLocationsOperationsService(base_api.BaseApiService):
    """Service class for the projects_locations_operations resource."""

    _NAME = 'projects_locations_operations'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsOperationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Cancel(self, request, global_params=None):
      r"""Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of `1`, corresponding to `Code.CANCELLED`.

      Args:
        request: (TransferapplianceProjectsLocationsOperationsCancelRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Cancel')
      return self._RunMethod(
          config, request, global_params=global_params)

    Cancel.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}:cancel',
        http_method='POST',
        method_id='transferappliance.projects.locations.operations.cancel',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}:cancel',
        request_field='cancelOperationRequest',
        request_type_name='TransferapplianceProjectsLocationsOperationsCancelRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.

      Args:
        request: (TransferapplianceProjectsLocationsOperationsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}',
        http_method='DELETE',
        method_id='transferappliance.projects.locations.operations.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOperationsDeleteRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

      Args:
        request: (TransferapplianceProjectsLocationsOperationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.operations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOperationsGetRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.

      Args:
        request: (TransferapplianceProjectsLocationsOperationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListOperationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/operations',
        http_method='GET',
        method_id='transferappliance.projects.locations.operations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['filter', 'pageSize', 'pageToken', 'returnPartialSuccess'],
        relative_path='v1alpha1/{+name}/operations',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOperationsListRequest',
        response_type_name='ListOperationsResponse',
        supports_download=False,
    )

  class ProjectsLocationsOrdersService(base_api.BaseApiService):
    """Service class for the projects_locations_orders resource."""

    _NAME = 'projects_locations_orders'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsOrdersService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new Order in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders',
        http_method='POST',
        method_id='transferappliance.projects.locations.orders.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['orderId', 'requestId', 'validateOnly'],
        relative_path='v1alpha1/{+parent}/orders',
        request_field='order',
        request_type_name='TransferapplianceProjectsLocationsOrdersCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a Order.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders/{ordersId}',
        http_method='DELETE',
        method_id='transferappliance.projects.locations.orders.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['etag', 'requestId', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOrdersDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets details of a single Order.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Order) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders/{ordersId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.orders.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOrdersGetRequest',
        response_type_name='Order',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists Orders in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListOrdersResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders',
        http_method='GET',
        method_id='transferappliance.projects.locations.orders.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1alpha1/{+parent}/orders',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsOrdersListRequest',
        response_type_name='ListOrdersResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates the parameters of a single Order.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders/{ordersId}',
        http_method='PATCH',
        method_id='transferappliance.projects.locations.orders.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['allowMissing', 'requestId', 'updateMask', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='order',
        request_type_name='TransferapplianceProjectsLocationsOrdersPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Submit(self, request, global_params=None):
      r"""Submit an Order, moving it from the DRAFT state to PREPARING and updating any appliances associated with the order by moving them from the DRAFT state to ACTIVE. This method will attempt to set and validate any required permissions for a workload's service accounts on the workload's resources (e.g. KMS key, Cloud Storage bucket) for all appliances associated with the order. The caller must have the appropriate permissions to manage permissions for these resources.

      Args:
        request: (TransferapplianceProjectsLocationsOrdersSubmitRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Submit')
      return self._RunMethod(
          config, request, global_params=global_params)

    Submit.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/orders/{ordersId}:submit',
        http_method='POST',
        method_id='transferappliance.projects.locations.orders.submit',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}:submit',
        request_field='submitOrderRequest',
        request_type_name='TransferapplianceProjectsLocationsOrdersSubmitRequest',
        response_type_name='Operation',
        supports_download=False,
    )

  class ProjectsLocationsSavedAddressesService(base_api.BaseApiService):
    """Service class for the projects_locations_savedAddresses resource."""

    _NAME = 'projects_locations_savedAddresses'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsSavedAddressesService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new SavedAddress in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsSavedAddressesCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/savedAddresses',
        http_method='POST',
        method_id='transferappliance.projects.locations.savedAddresses.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['requestId', 'savedAddressId', 'validateOnly'],
        relative_path='v1alpha1/{+parent}/savedAddresses',
        request_field='savedAddress',
        request_type_name='TransferapplianceProjectsLocationsSavedAddressesCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a single SavedAddress.

      Args:
        request: (TransferapplianceProjectsLocationsSavedAddressesDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/savedAddresses/{savedAddressesId}',
        http_method='DELETE',
        method_id='transferappliance.projects.locations.savedAddresses.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['etag', 'requestId', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsSavedAddressesDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets details of a single SavedAddress.

      Args:
        request: (TransferapplianceProjectsLocationsSavedAddressesGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (SavedAddress) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/savedAddresses/{savedAddressesId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.savedAddresses.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsSavedAddressesGetRequest',
        response_type_name='SavedAddress',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists SavedAddresses in a given project and location.

      Args:
        request: (TransferapplianceProjectsLocationsSavedAddressesListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListSavedAddressesResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/savedAddresses',
        http_method='GET',
        method_id='transferappliance.projects.locations.savedAddresses.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1alpha1/{+parent}/savedAddresses',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsSavedAddressesListRequest',
        response_type_name='ListSavedAddressesResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates the parameters of a single SavedAddress.

      Args:
        request: (TransferapplianceProjectsLocationsSavedAddressesPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}/savedAddresses/{savedAddressesId}',
        http_method='PATCH',
        method_id='transferappliance.projects.locations.savedAddresses.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['allowMissing', 'requestId', 'updateMask', 'validateOnly'],
        relative_path='v1alpha1/{+name}',
        request_field='savedAddress',
        request_type_name='TransferapplianceProjectsLocationsSavedAddressesPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

  class ProjectsLocationsService(base_api.BaseApiService):
    """Service class for the projects_locations resource."""

    _NAME = 'projects_locations'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsLocationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets information about a location.

      Args:
        request: (TransferapplianceProjectsLocationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Location) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations/{locationsId}',
        http_method='GET',
        method_id='transferappliance.projects.locations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1alpha1/{+name}',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsGetRequest',
        response_type_name='Location',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists information about the supported locations for this service. This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: * **Global locations**: If `name` is empty, the method lists the public locations available to all projects. * **Project-specific locations**: If `name` follows the format `projects/{project}`, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project. For gRPC and client library implementations, the resource name is passed as the `name` field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

      Args:
        request: (TransferapplianceProjectsLocationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListLocationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1alpha1/projects/{projectsId}/locations',
        http_method='GET',
        method_id='transferappliance.projects.locations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['extraLocationTypes', 'filter', 'pageSize', 'pageToken'],
        relative_path='v1alpha1/{+name}/locations',
        request_field='',
        request_type_name='TransferapplianceProjectsLocationsListRequest',
        response_type_name='ListLocationsResponse',
        supports_download=False,
    )

  class ProjectsService(base_api.BaseApiService):
    """Service class for the projects resource."""

    _NAME = 'projects'

    def __init__(self, client):
      super(TransferapplianceV1alpha1.ProjectsService, self).__init__(client)
      self._upload_configs = {
          }



# Copyright 2026 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orchestration_pipelines_models/pipeline_v1_model/protos/orchestration_pipeline.proto
"""Generated protocol buffer code."""
from cloudsdk.google.protobuf.internal import builder as _builder
from cloudsdk.google.protobuf import descriptor as _descriptor
from cloudsdk.google.protobuf import descriptor_pool as _descriptor_pool
from cloudsdk.google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cloudsdk.google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from orchestration_pipelines_models.pipeline_v1_model.protos import (
    validation_pb2 as orchestration__pipelines__models_dot_pipeline__v1__model_dot_protos_dot_validation__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\nTorchestration_pipelines_models/pipeline_v1_model/protos/orchestration_pipeline.proto\x12\x0fpipeline_models\x1a\x1cgoogle/protobuf/struct.proto\x1aHorchestration_pipelines_models/pipeline_v1_model/protos/validation.proto\"\xbc\x03\n\x15OrchestrationPipeline\x12\x1b\n\rmodel_version\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x35\n\x0bpipeline_id\x18\x02 \x01(\tB \x80\xb5\x18\x01\x8a\xb5\x18\x10^[a-zA-Z0-9_-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x35\n\x06runner\x18\x04 \x01(\x0e\x32\x1f.pipeline_models.PipelineRunnerB\x04\xa0\xb5\x18\x01\x12\x30\n\x05owner\x18\x05 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_#-]+$\xa8\xb5\x18\x01\xb0\xb5\x18 \x12\x31\n\x08\x64\x65\x66\x61ults\x18\x06 \x01(\x0b\x32\x19.pipeline_models.DefaultsB\x04\x80\xb5\x18\x01\x12*\n\x08triggers\x18\x07 \x03(\x0b\x32\x18.pipeline_models.Trigger\x12.\n\x07\x61\x63tions\x18\x08 \x03(\x0b\x32\x17.pipeline_models.ActionB\x04\x98\xb5\x18\x01\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x34\n\rnotifications\x18\n \x01(\x0b\x32\x1d.pipeline_models.Notification\"~\n\x08\x44\x65\x66\x61ults\x12\x18\n\nproject_id\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x16\n\x08location\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12@\n\x10\x65xecution_config\x18\x03 \x01(\x0b\x32 .pipeline_models.ExecutionConfigB\x04\x80\xb5\x18\x01\"/\n\x0f\x45xecutionConfig\x12\x1c\n\x07retries\x18\x01 \x01(\x05\x42\x0b\x91\xb5\x18\x00\x00\x00\x00\x00\x00\x00\x00\"\"\n\x11OnPipelineFailure\x12\r\n\x05\x65mail\x18\x01 \x03(\t\"O\n\x0cNotification\x12?\n\x13on_pipeline_failure\x18\x01 \x01(\x0b\x32\".pipeline_models.OnPipelineFailure\"\x8c\x01\n\x0fScheduleTrigger\x12\x1a\n\x08interval\x18\x01 \x01(\tB\x08\x80\xb5\x18\x01\xb8\xb5\x18\x01\x12\x1c\n\nstart_time\x18\x02 \x01(\tB\x08\x80\xb5\x18\x01\xc0\xb5\x18\x01\x12\x16\n\x08\x65nd_time\x18\x03 \x01(\tB\x04\xc0\xb5\x18\x01\x12\x0f\n\x07\x63\x61tchup\x18\x04 \x01(\x08\x12\x16\n\x08timezone\x18\x05 \x01(\tB\x04\xd0\xb5\x18\x01\"J\n\x07Trigger\x12\x34\n\x08schedule\x18\x01 \x01(\x0b\x32 .pipeline_models.ScheduleTriggerH\x00\x42\t\n\x07trigger\"\r\n\x0bLocalEngine\"Z\n\x0e\x42igQueryEngine\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65stination_table\x18\x02 \x01(\t\x12\x1b\n\x13impersonation_chain\x18\x03 \x03(\t\"\xc0\x01\n\x13\x44\x61taprocOnGceEngine\x12Q\n\x10\x65xisting_cluster\x18\x01 \x01(\x0b\x32\x35.pipeline_models.DataprocExistingClusterConfigurationH\x00\x12L\n\x11\x65phemeral_cluster\x18\x02 \x01(\x0b\x32/.pipeline_models.DataprocEphemeralConfigurationH\x00\x42\x08\n\x06\x63onfig\"\x93\x02\n$DataprocExistingClusterConfiguration\x12\x1a\n\x0c\x63luster_name\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x1b\n\x13impersonation_chain\x18\x04 \x03(\t\x12Y\n\nproperties\x18\x05 \x03(\x0b\x32\x45.pipeline_models.DataprocExistingClusterConfiguration.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x02\n\x1e\x44\x61taprocEphemeralConfiguration\x12\x1a\n\x0c\x63luster_name\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12O\n\x10resource_profile\x18\x04 \x01(\x0b\x32/.pipeline_models.DataprocClusterResourceProfileB\x04\x80\xb5\x18\x01\x12S\n\nproperties\x18\x05 \x03(\x0b\x32?.pipeline_models.DataprocEphemeralConfiguration.PropertiesEntry\x12\x1b\n\x13impersonation_chain\x18\x06 \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x02\n\x1e\x44\x61taprocClusterResourceProfile\x12N\n\x06inline\x18\x01 \x01(\x0b\x32<.pipeline_models.DataprocClusterResourceProfile.InlineConfigH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12\x1e\n\x14\x65xternal_config_path\x18\x03 \x01(\tH\x00\x12O\n\toverrides\x18\x04 \x01(\x0b\x32<.pipeline_models.DataprocClusterResourceProfile.InlineConfig\x1a\x80\x01\n\x0cInlineConfig\x12\x35\n\x0e\x63luster_config\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x42\x0e\n\x0c\x63onfig_aliasB\x08\n\x06\x63onfig\"\xeb\x02\n\x1c\x44\x61taprocBatchResourceProfile\x12L\n\x06inline\x18\x01 \x01(\x0b\x32:.pipeline_models.DataprocBatchResourceProfile.InlineConfigH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12\x1e\n\x14\x65xternal_config_path\x18\x03 \x01(\tH\x00\x12M\n\toverrides\x18\x04 \x01(\x0b\x32:.pipeline_models.DataprocBatchResourceProfile.InlineConfig\x1at\n\x0cInlineConfig\x12/\n\x0eruntime_config\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x65nvironment_config\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\n\x06\x63onfig\"\x9d\x01\n\x1d\x44\x61taprocServerlessBatchEngine\x12\x10\n\x08location\x18\x01 \x01(\t\x12M\n\x10resource_profile\x18\x02 \x01(\x0b\x32-.pipeline_models.DataprocBatchResourceProfileB\x04\x80\xb5\x18\x01\x12\x1b\n\x13impersonation_chain\x18\x03 \x03(\t\"\xcb\x02\n\x06\x41\x63tion\x12/\n\x06python\x18\x01 \x01(\x0b\x32\x1d.pipeline_models.PythonActionH\x00\x12\x31\n\x07pyspark\x18\x02 \x01(\x0b\x32\x1e.pipeline_models.PysparkActionH\x00\x12\x33\n\x08notebook\x18\x03 \x01(\x0b\x32\x1f.pipeline_models.NotebookActionH\x00\x12)\n\x03sql\x18\x04 \x01(\x0b\x32\x1a.pipeline_models.SqlActionH\x00\x12\x33\n\x08pipeline\x18\x05 \x01(\x0b\x32\x1f.pipeline_models.PipelineActionH\x00\x12>\n\x0e\x64\x61ta_ingestion\x18\x06 \x01(\x0b\x32$.pipeline_models.DataIngestionActionH\x00\x42\x08\n\x06\x61\x63tion\"\xcb\x02\n\x0cPythonAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12\x1c\n\x0emain_file_path\x18\x04 \x01(\tB\x04\x80\xb5\x18\x01\x12\x1d\n\x0fpython_callable\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12*\n\top_kwargs\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x37\n\x0b\x65nvironment\x18\x07 \x01(\x0b\x32\".pipeline_models.PythonEnvironment\x12\x33\n\x06\x65ngine\x18\x08 \x01(\x0b\x32\x1d.pipeline_models.PythonEngineB\x04\x80\xb5\x18\x01\"\x95\x02\n\x11PythonEnvironment\x12\x45\n\x0crequirements\x18\x01 \x01(\x0b\x32/.pipeline_models.PythonEnvironment.Requirements\x12\x1c\n\x14system_site_packages\x18\x02 \x01(\x08\x1a\"\n\x12InlineRequirements\x12\x0c\n\x04list\x18\x01 \x03(\t\x1aw\n\x0cRequirements\x12G\n\x06inline\x18\x01 \x01(\x0b\x32\x35.pipeline_models.PythonEnvironment.InlineRequirementsH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x42\x0e\n\x0crequirements\"G\n\x0cPythonEngine\x12-\n\x05local\x18\x01 \x01(\x0b\x32\x1c.pipeline_models.LocalEngineH\x00\x42\x08\n\x06\x65ngine\"\xc3\x02\n\rPysparkAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12\x34\n\x06\x65ngine\x18\x04 \x01(\x0b\x32\x1e.pipeline_models.PysparkEngineB\x04\x80\xb5\x18\x01\x12\x1c\n\x0emain_file_path\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12\x14\n\x0c\x61rchive_uris\x18\x06 \x03(\t\x12\x16\n\x0estaging_bucket\x18\x07 \x01(\t\x12\x10\n\x08py_files\x18\x08 \x03(\t\x12\x38\n\x0b\x65nvironment\x18\t \x01(\x0b\x32#.pipeline_models.PysparkEnvironment\"\xa9\x01\n\rPysparkEngine\x12?\n\x0f\x64\x61taproc_on_gce\x18\x01 \x01(\x0b\x32$.pipeline_models.DataprocOnGceEngineH\x00\x12M\n\x13\x64\x61taproc_serverless\x18\x02 \x01(\x0b\x32..pipeline_models.DataprocServerlessBatchEngineH\x00\x42\x08\n\x06\x65ngine\"\x8c\x01\n\x12PysparkEnvironment\x12\x46\n\x0crequirements\x18\x01 \x01(\x0b\x32\x30.pipeline_models.PysparkEnvironment.Requirements\x1a.\n\x0cRequirements\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x42\x0e\n\x0crequirements\"\xb4\x02\n\x0eNotebookAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12\x35\n\x06\x65ngine\x18\x04 \x01(\x0b\x32\x1f.pipeline_models.NotebookEngineB\x04\x80\xb5\x18\x01\x12\x1c\n\x0emain_file_path\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12\x14\n\x0c\x61rchive_uris\x18\x06 \x03(\t\x12\x16\n\x0estaging_bucket\x18\x07 \x01(\t\x12\x39\n\x0b\x65nvironment\x18\x08 \x01(\x0b\x32$.pipeline_models.NotebookEnvironment\"\xaa\x01\n\x0eNotebookEngine\x12?\n\x0f\x64\x61taproc_on_gce\x18\x01 \x01(\x0b\x32$.pipeline_models.DataprocOnGceEngineH\x00\x12M\n\x13\x64\x61taproc_serverless\x18\x02 \x01(\x0b\x32..pipeline_models.DataprocServerlessBatchEngineH\x00\x42\x08\n\x06\x65ngine\"\x8e\x01\n\x13NotebookEnvironment\x12G\n\x0crequirements\x18\x01 \x01(\x0b\x32\x31.pipeline_models.NotebookEnvironment.Requirements\x1a.\n\x0cRequirements\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x42\x0e\n\x0crequirements\"\xd0\x01\n\tSqlAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12\x30\n\x06\x65ngine\x18\x04 \x01(\x0b\x32\x1a.pipeline_models.SqlEngineB\x04\x80\xb5\x18\x01\x12+\n\x05query\x18\x05 \x01(\x0b\x32\x16.pipeline_models.QueryB\x04\x80\xb5\x18\x01\"2\n\x05Query\x12\x10\n\x06inline\x18\x01 \x01(\tH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x42\x07\n\x05query\"\xda\x01\n\tSqlEngine\x12\x33\n\x08\x62igquery\x18\x01 \x01(\x0b\x32\x1f.pipeline_models.BigQueryEngineH\x00\x12M\n\x13\x64\x61taproc_serverless\x18\x02 \x01(\x0b\x32..pipeline_models.DataprocServerlessBatchEngineH\x00\x12?\n\x0f\x64\x61taproc_on_gce\x18\x03 \x01(\x0b\x32$.pipeline_models.DataprocOnGceEngineH\x00\x42\x08\n\x06\x65ngine\"\xb3\x01\n\x0ePipelineAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12;\n\tframework\x18\x04 \x01(\x0b\x32\".pipeline_models.PipelineFrameworkB\x04\x80\xb5\x18\x01\"\x8e\x01\n\x11PipelineFramework\x12\x30\n\x03\x64\x62t\x18\x01 \x01(\x0b\x32!.pipeline_models.DbtFrameworkSpecH\x00\x12:\n\x08\x64\x61taform\x18\x02 \x01(\x0b\x32&.pipeline_models.DataformFrameworkSpecH\x00\x42\x0b\n\tframework\"_\n\x10\x44\x62tFrameworkSpec\x12>\n\x0e\x61irflow_worker\x18\x01 \x01(\x0b\x32$.pipeline_models.DbtAirflowExecutionH\x00\x42\x0b\n\texecution\"\xb0\x01\n\x15\x44\x61taformFrameworkSpec\x12\x45\n\x10\x64\x61taform_service\x18\x01 \x01(\x0b\x32).pipeline_models.DataformServiceExecutionH\x00\x12\x43\n\x0e\x61irflow_worker\x18\x02 \x01(\x0b\x32).pipeline_models.DataformAirflowExecutionH\x00\x42\x0b\n\texecution\"\x93\x01\n\x18\x44\x61taformServiceExecution\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1b\n\rrepository_id\x18\x03 \x01(\tB\x04\x80\xb5\x18\x01\x12\x34\n\x13workflow_invocation\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"`\n\x13\x44\x62tAirflowExecution\x12$\n\x16project_directory_path\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x15\n\rselect_models\x18\x02 \x03(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"@\n\x18\x44\x61taformAirflowExecution\x12$\n\x16project_directory_path\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"\xbf\x01\n\x13\x44\x61taIngestionAction\x12/\n\x04name\x18\x01 \x01(\tB!\x80\xb5\x18\x01\x8a\xb5\x18\x11^[a-zA-Z0-9_.-]+$\xa8\xb5\x18\x01\xb0\xb5\x18@\x12\x12\n\ndepends_on\x18\x02 \x03(\t\x12\x1f\n\x11\x65xecution_timeout\x18\x03 \x01(\tB\x04\xc8\xb5\x18\x01\x12\x38\n\x0c\x62igquery_dts\x18\x04 \x01(\x0b\x32 .pipeline_models.BigQueryDtsSpecH\x00\x42\x08\n\x06\x63onfig\"\xbc\x01\n\x0f\x42igQueryDtsSpec\x12\"\n\x12transfer_config_id\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01H\x00\x12/\n\x0eruntime_params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1b\n\x13impersonation_chain\x18\x03 \x03(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\tB\x11\n\x0ftransfer_config*<\n\x0ePipelineRunner\x12\x1d\n\x19pipeline_runner_undefined\x10\x00\x12\x0b\n\x07\x61irflow\x10\x01\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR,
    'orchestration_pipelines_models.pipeline_v1_model.protos.orchestration_pipeline_pb2',
    globals(),
)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['model_version']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name[
        'model_version'
    ]._serialized_options = b'\200\265\030\001'
    _ORCHESTRATIONPIPELINE.fields_by_name['pipeline_id']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['pipeline_id']._serialized_options = (
        b'\200\265\030\001\212\265\030\020^[a-zA-Z0-9_-]+$\250\265\030\001\260\265\030@'
    )
    _ORCHESTRATIONPIPELINE.fields_by_name['runner']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['runner']._serialized_options = (
        b'\240\265\030\001'
    )
    _ORCHESTRATIONPIPELINE.fields_by_name['owner']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['owner']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_#-]+$\250\265\030\001\260\265\030 '
    )
    _ORCHESTRATIONPIPELINE.fields_by_name['defaults']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['defaults']._serialized_options = (
        b'\200\265\030\001'
    )
    _ORCHESTRATIONPIPELINE.fields_by_name['actions']._options = None
    _ORCHESTRATIONPIPELINE.fields_by_name['actions']._serialized_options = (
        b'\230\265\030\001'
    )
    _DEFAULTS.fields_by_name['project_id']._options = None
    _DEFAULTS.fields_by_name['project_id']._serialized_options = (
        b'\200\265\030\001'
    )
    _DEFAULTS.fields_by_name['location']._options = None
    _DEFAULTS.fields_by_name['location']._serialized_options = (
        b'\200\265\030\001'
    )
    _DEFAULTS.fields_by_name['execution_config']._options = None
    _DEFAULTS.fields_by_name['execution_config']._serialized_options = (
        b'\200\265\030\001'
    )
    _EXECUTIONCONFIG.fields_by_name['retries']._options = None
    _EXECUTIONCONFIG.fields_by_name['retries']._serialized_options = (
        b'\221\265\030\000\000\000\000\000\000\000\000'
    )
    _SCHEDULETRIGGER.fields_by_name['interval']._options = None
    _SCHEDULETRIGGER.fields_by_name['interval']._serialized_options = (
        b'\200\265\030\001\270\265\030\001'
    )
    _SCHEDULETRIGGER.fields_by_name['start_time']._options = None
    _SCHEDULETRIGGER.fields_by_name['start_time']._serialized_options = (
        b'\200\265\030\001\300\265\030\001'
    )
    _SCHEDULETRIGGER.fields_by_name['end_time']._options = None
    _SCHEDULETRIGGER.fields_by_name['end_time']._serialized_options = (
        b'\300\265\030\001'
    )
    _SCHEDULETRIGGER.fields_by_name['timezone']._options = None
    _SCHEDULETRIGGER.fields_by_name['timezone']._serialized_options = (
        b'\320\265\030\001'
    )
    _DATAPROCEXISTINGCLUSTERCONFIGURATION_PROPERTIESENTRY._options = None
    _DATAPROCEXISTINGCLUSTERCONFIGURATION_PROPERTIESENTRY._serialized_options = (
        b'8\001'
    )
    _DATAPROCEXISTINGCLUSTERCONFIGURATION.fields_by_name[
        'cluster_name'
    ]._options = None
    _DATAPROCEXISTINGCLUSTERCONFIGURATION.fields_by_name[
        'cluster_name'
    ]._serialized_options = b'\200\265\030\001'
    _DATAPROCEPHEMERALCONFIGURATION_PROPERTIESENTRY._options = None
    _DATAPROCEPHEMERALCONFIGURATION_PROPERTIESENTRY._serialized_options = (
        b'8\001'
    )
    _DATAPROCEPHEMERALCONFIGURATION.fields_by_name['cluster_name']._options = (
        None
    )
    _DATAPROCEPHEMERALCONFIGURATION.fields_by_name[
        'cluster_name'
    ]._serialized_options = b'\200\265\030\001'
    _DATAPROCEPHEMERALCONFIGURATION.fields_by_name[
        'resource_profile'
    ]._options = None
    _DATAPROCEPHEMERALCONFIGURATION.fields_by_name[
        'resource_profile'
    ]._serialized_options = b'\200\265\030\001'
    _DATAPROCCLUSTERRESOURCEPROFILE_INLINECONFIG.fields_by_name[
        'cluster_config'
    ]._options = None
    _DATAPROCCLUSTERRESOURCEPROFILE_INLINECONFIG.fields_by_name[
        'cluster_config'
    ]._serialized_options = b'\030\001'
    _DATAPROCSERVERLESSBATCHENGINE.fields_by_name[
        'resource_profile'
    ]._options = None
    _DATAPROCSERVERLESSBATCHENGINE.fields_by_name[
        'resource_profile'
    ]._serialized_options = b'\200\265\030\001'
    _PYTHONACTION.fields_by_name['name']._options = None
    _PYTHONACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _PYTHONACTION.fields_by_name['execution_timeout']._options = None
    _PYTHONACTION.fields_by_name['execution_timeout']._serialized_options = (
        b'\310\265\030\001'
    )
    _PYTHONACTION.fields_by_name['main_file_path']._options = None
    _PYTHONACTION.fields_by_name['main_file_path']._serialized_options = (
        b'\200\265\030\001'
    )
    _PYTHONACTION.fields_by_name['python_callable']._options = None
    _PYTHONACTION.fields_by_name['python_callable']._serialized_options = (
        b'\200\265\030\001'
    )
    _PYTHONACTION.fields_by_name['engine']._options = None
    _PYTHONACTION.fields_by_name['engine']._serialized_options = (
        b'\200\265\030\001'
    )
    _PYSPARKACTION.fields_by_name['name']._options = None
    _PYSPARKACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _PYSPARKACTION.fields_by_name['execution_timeout']._options = None
    _PYSPARKACTION.fields_by_name['execution_timeout']._serialized_options = (
        b'\310\265\030\001'
    )
    _PYSPARKACTION.fields_by_name['engine']._options = None
    _PYSPARKACTION.fields_by_name['engine']._serialized_options = (
        b'\200\265\030\001'
    )
    _PYSPARKACTION.fields_by_name['main_file_path']._options = None
    _PYSPARKACTION.fields_by_name['main_file_path']._serialized_options = (
        b'\200\265\030\001'
    )
    _NOTEBOOKACTION.fields_by_name['name']._options = None
    _NOTEBOOKACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _NOTEBOOKACTION.fields_by_name['execution_timeout']._options = None
    _NOTEBOOKACTION.fields_by_name['execution_timeout']._serialized_options = (
        b'\310\265\030\001'
    )
    _NOTEBOOKACTION.fields_by_name['engine']._options = None
    _NOTEBOOKACTION.fields_by_name['engine']._serialized_options = (
        b'\200\265\030\001'
    )
    _NOTEBOOKACTION.fields_by_name['main_file_path']._options = None
    _NOTEBOOKACTION.fields_by_name['main_file_path']._serialized_options = (
        b'\200\265\030\001'
    )
    _SQLACTION.fields_by_name['name']._options = None
    _SQLACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _SQLACTION.fields_by_name['execution_timeout']._options = None
    _SQLACTION.fields_by_name['execution_timeout']._serialized_options = (
        b'\310\265\030\001'
    )
    _SQLACTION.fields_by_name['engine']._options = None
    _SQLACTION.fields_by_name['engine']._serialized_options = (
        b'\200\265\030\001'
    )
    _SQLACTION.fields_by_name['query']._options = None
    _SQLACTION.fields_by_name['query']._serialized_options = b'\200\265\030\001'
    _PIPELINEACTION.fields_by_name['name']._options = None
    _PIPELINEACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _PIPELINEACTION.fields_by_name['execution_timeout']._options = None
    _PIPELINEACTION.fields_by_name['execution_timeout']._serialized_options = (
        b'\310\265\030\001'
    )
    _PIPELINEACTION.fields_by_name['framework']._options = None
    _PIPELINEACTION.fields_by_name['framework']._serialized_options = (
        b'\200\265\030\001'
    )
    _DATAFORMSERVICEEXECUTION.fields_by_name['repository_id']._options = None
    _DATAFORMSERVICEEXECUTION.fields_by_name[
        'repository_id'
    ]._serialized_options = b'\200\265\030\001'
    _DBTAIRFLOWEXECUTION.fields_by_name['project_directory_path']._options = (
        None
    )
    _DBTAIRFLOWEXECUTION.fields_by_name[
        'project_directory_path'
    ]._serialized_options = b'\200\265\030\001'
    _DATAFORMAIRFLOWEXECUTION.fields_by_name[
        'project_directory_path'
    ]._options = None
    _DATAFORMAIRFLOWEXECUTION.fields_by_name[
        'project_directory_path'
    ]._serialized_options = b'\200\265\030\001'
    _DATAINGESTIONACTION.fields_by_name['name']._options = None
    _DATAINGESTIONACTION.fields_by_name['name']._serialized_options = (
        b'\200\265\030\001\212\265\030\021^[a-zA-Z0-9_.-]+$\250\265\030\001\260\265\030@'
    )
    _DATAINGESTIONACTION.fields_by_name['execution_timeout']._options = None
    _DATAINGESTIONACTION.fields_by_name[
        'execution_timeout'
    ]._serialized_options = b'\310\265\030\001'
    _BIGQUERYDTSSPEC.fields_by_name['transfer_config_id']._options = None
    _BIGQUERYDTSSPEC.fields_by_name[
        'transfer_config_id'
    ]._serialized_options = b'\200\265\030\001'
    _PIPELINERUNNER._serialized_start = 7084
    _PIPELINERUNNER._serialized_end = 7144
    _ORCHESTRATIONPIPELINE._serialized_start = 210
    _ORCHESTRATIONPIPELINE._serialized_end = 654
    _DEFAULTS._serialized_start = 656
    _DEFAULTS._serialized_end = 782
    _EXECUTIONCONFIG._serialized_start = 784
    _EXECUTIONCONFIG._serialized_end = 831
    _ONPIPELINEFAILURE._serialized_start = 833
    _ONPIPELINEFAILURE._serialized_end = 867
    _NOTIFICATION._serialized_start = 869
    _NOTIFICATION._serialized_end = 948
    _SCHEDULETRIGGER._serialized_start = 951
    _SCHEDULETRIGGER._serialized_end = 1091
    _TRIGGER._serialized_start = 1093
    _TRIGGER._serialized_end = 1167
    _LOCALENGINE._serialized_start = 1169
    _LOCALENGINE._serialized_end = 1182
    _BIGQUERYENGINE._serialized_start = 1184
    _BIGQUERYENGINE._serialized_end = 1274
    _DATAPROCONGCEENGINE._serialized_start = 1277
    _DATAPROCONGCEENGINE._serialized_end = 1469
    _DATAPROCEXISTINGCLUSTERCONFIGURATION._serialized_start = 1472
    _DATAPROCEXISTINGCLUSTERCONFIGURATION._serialized_end = 1747
    _DATAPROCEXISTINGCLUSTERCONFIGURATION_PROPERTIESENTRY._serialized_start = (
        1698
    )
    _DATAPROCEXISTINGCLUSTERCONFIGURATION_PROPERTIESENTRY._serialized_end = 1747
    _DATAPROCEPHEMERALCONFIGURATION._serialized_start = 1750
    _DATAPROCEPHEMERALCONFIGURATION._serialized_end = 2094
    _DATAPROCEPHEMERALCONFIGURATION_PROPERTIESENTRY._serialized_start = 1698
    _DATAPROCEPHEMERALCONFIGURATION_PROPERTIESENTRY._serialized_end = 1747
    _DATAPROCCLUSTERRESOURCEPROFILE._serialized_start = 2097
    _DATAPROCCLUSTERRESOURCEPROFILE._serialized_end = 2479
    _DATAPROCCLUSTERRESOURCEPROFILE_INLINECONFIG._serialized_start = 2341
    _DATAPROCCLUSTERRESOURCEPROFILE_INLINECONFIG._serialized_end = 2469
    _DATAPROCBATCHRESOURCEPROFILE._serialized_start = 2482
    _DATAPROCBATCHRESOURCEPROFILE._serialized_end = 2845
    _DATAPROCBATCHRESOURCEPROFILE_INLINECONFIG._serialized_start = 2719
    _DATAPROCBATCHRESOURCEPROFILE_INLINECONFIG._serialized_end = 2835
    _DATAPROCSERVERLESSBATCHENGINE._serialized_start = 2848
    _DATAPROCSERVERLESSBATCHENGINE._serialized_end = 3005
    _ACTION._serialized_start = 3008
    _ACTION._serialized_end = 3339
    _PYTHONACTION._serialized_start = 3342
    _PYTHONACTION._serialized_end = 3673
    _PYTHONENVIRONMENT._serialized_start = 3676
    _PYTHONENVIRONMENT._serialized_end = 3953
    _PYTHONENVIRONMENT_INLINEREQUIREMENTS._serialized_start = 3798
    _PYTHONENVIRONMENT_INLINEREQUIREMENTS._serialized_end = 3832
    _PYTHONENVIRONMENT_REQUIREMENTS._serialized_start = 3834
    _PYTHONENVIRONMENT_REQUIREMENTS._serialized_end = 3953
    _PYTHONENGINE._serialized_start = 3955
    _PYTHONENGINE._serialized_end = 4026
    _PYSPARKACTION._serialized_start = 4029
    _PYSPARKACTION._serialized_end = 4352
    _PYSPARKENGINE._serialized_start = 4355
    _PYSPARKENGINE._serialized_end = 4524
    _PYSPARKENVIRONMENT._serialized_start = 4527
    _PYSPARKENVIRONMENT._serialized_end = 4667
    _PYSPARKENVIRONMENT_REQUIREMENTS._serialized_start = 4621
    _PYSPARKENVIRONMENT_REQUIREMENTS._serialized_end = 4667
    _NOTEBOOKACTION._serialized_start = 4670
    _NOTEBOOKACTION._serialized_end = 4978
    _NOTEBOOKENGINE._serialized_start = 4981
    _NOTEBOOKENGINE._serialized_end = 5151
    _NOTEBOOKENVIRONMENT._serialized_start = 5154
    _NOTEBOOKENVIRONMENT._serialized_end = 5296
    _NOTEBOOKENVIRONMENT_REQUIREMENTS._serialized_start = 4621
    _NOTEBOOKENVIRONMENT_REQUIREMENTS._serialized_end = 4667
    _SQLACTION._serialized_start = 5299
    _SQLACTION._serialized_end = 5507
    _QUERY._serialized_start = 5509
    _QUERY._serialized_end = 5559
    _SQLENGINE._serialized_start = 5562
    _SQLENGINE._serialized_end = 5780
    _PIPELINEACTION._serialized_start = 5783
    _PIPELINEACTION._serialized_end = 5962
    _PIPELINEFRAMEWORK._serialized_start = 5965
    _PIPELINEFRAMEWORK._serialized_end = 6107
    _DBTFRAMEWORKSPEC._serialized_start = 6109
    _DBTFRAMEWORKSPEC._serialized_end = 6204
    _DATAFORMFRAMEWORKSPEC._serialized_start = 6207
    _DATAFORMFRAMEWORKSPEC._serialized_end = 6383
    _DATAFORMSERVICEEXECUTION._serialized_start = 6386
    _DATAFORMSERVICEEXECUTION._serialized_end = 6533
    _DBTAIRFLOWEXECUTION._serialized_start = 6535
    _DBTAIRFLOWEXECUTION._serialized_end = 6631
    _DATAFORMAIRFLOWEXECUTION._serialized_start = 6633
    _DATAFORMAIRFLOWEXECUTION._serialized_end = 6697
    _DATAINGESTIONACTION._serialized_start = 6700
    _DATAINGESTIONACTION._serialized_end = 6891
    _BIGQUERYDTSSPEC._serialized_start = 6894
    _BIGQUERYDTSSPEC._serialized_end = 7082
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Utility functions for the KMS Inventory CLI."""


from apitools.base.py import list_pager
from googlecloudsdk.api_lib.util import apis

DEFAULT_API_NAME = 'kmsinventory'
DEFAULT_API_VERSION = 'v1'


# The messages module can also be accessed from client.MESSAGES_MODULE
def GetClientInstance():
  return apis.GetClientInstance(DEFAULT_API_NAME, DEFAULT_API_VERSION)


def GetMessagesModule():
  return apis.GetMessagesModule(DEFAULT_API_NAME, DEFAULT_API_VERSION)


def ListKeys(project, args):
  client = GetClientInstance()
  request = GetMessagesModule().KmsinventoryProjectsCryptoKeysListRequest(
      parent='projects/' + project)

  return list_pager.YieldFromList(
      client.projects_cryptoKeys,
      request,
      limit=args.limit,
      batch_size_attribute='pageSize',
      batch_size=args.page_size,
      field='cryptoKeys')


def GetProtectedResourcesSummary(name, fallback_scope=None):
  """Gets a summary of protected resources for a given CryptoKey.

  Args:
    name: The resource name of the CryptoKey.
    fallback_scope: Optional. The scope to fall back to if the summary cannot
      be generated for the specified CryptoKey.

  Returns:
    A ProtectedResourcesSummary message.
  """
  client = GetClientInstance()
  messages = GetMessagesModule()
  fallback_scope_enum = None
  if fallback_scope is not None:
    fallback_scope_enum = (
        messages.KmsinventoryProjectsLocationsKeyRingsCryptoKeysGetProtectedResourcesSummaryRequest.FallbackScopeValueValuesEnum(
            fallback_scope
        )
    )
  request = messages.KmsinventoryProjectsLocationsKeyRingsCryptoKeysGetProtectedResourcesSummaryRequest(
      name=name,
      fallbackScope=fallback_scope_enum
  )
  return client.projects_locations_keyRings_cryptoKeys.GetProtectedResourcesSummary(
      request
  )


def SearchProtectedResources(scope, key_name, resource_types, args):
  """Searches for protected resources within a given scope.

  Args:
    scope: The scope of the search, can be 'organizations/ORG_ID' or
      'projects/PROJECT_ID'.
    key_name: The name of the crypto key.
    resource_types: A list of resource types to filter the search.
    args: The command line arguments, including limit and page_size.

  Returns:
    A generator yielding protected resources.
  """
  client = GetClientInstance()
  if scope.startswith('projects/'):
    service = client.projects_protectedResources
    request = (
        GetMessagesModule().KmsinventoryProjectsProtectedResourcesSearchRequest(
            scope=scope, cryptoKey=key_name, resourceTypes=resource_types
        )
    )
  else:
    service = client.organizations_protectedResources
    request = GetMessagesModule().KmsinventoryOrganizationsProtectedResourcesSearchRequest(
        scope=scope, cryptoKey=key_name, resourceTypes=resource_types
    )

  return list_pager.YieldFromList(
      service,
      request,
      method='Search',
      limit=args.limit,
      batch_size_attribute='pageSize',
      batch_size=args.page_size,
      field='protectedResources',
  )



#!/usr/bin/env python
"""The BQ CLI `insert` command."""

import sys
from typing import Optional, TextIO

from absl import app
from absl import flags

import bq_flags
import bq_utils
from clients import client_table
from clients import utils as bq_client_utils
from frontend import bigquery_command
from frontend import bq_cached_client
from utils import bq_error
from utils import bq_id_utils
from utils import bq_processor_utils
from pyglib import stringutil

FLAGS = flags.FLAGS

# These aren't relevant for user-facing docstrings:
# pylint: disable=g-doc-return-or-yield
# pylint: disable=g-doc-args


class Insert(bigquery_command.BigqueryCmd):
  usage = """insert [-s] [-i] [-x=<suffix>] <table identifier> [file]"""
  command = 'insert'

  def __init__(self, name: str, fv: flags.FlagValues):
    super(Insert, self).__init__(name, fv)
    flags.DEFINE_boolean(
        'skip_invalid_rows',
        None,
        'Attempt to insert any valid rows, even if invalid rows are present.',
        short_name='s',
        flag_values=fv,
    )
    flags.DEFINE_boolean(
        'ignore_unknown_values',
        None,
        'Ignore any values in a row that are not present in the schema.',
        short_name='i',
        flag_values=fv,
    )
    flags.DEFINE_string(
        'template_suffix',
        None,
        'If specified, treats the destination table as a base template, and '
        'inserts the rows into an instance table named '
        '"{destination}{templateSuffix}". BigQuery will manage creation of the '
        'instance table, using the schema of the base template table.',
        short_name='x',
        flag_values=fv,
    )
    flags.DEFINE_string(
        'insert_id',
        None,
        'Used to ensure repeat executions do not add unintended data. '
        'A present insert_id value will be appended to the row number of '
        'each row to be inserted and used as the insertId field for the row. '
        'Internally the insertId field is used for deduping of inserted rows.',
        flag_values=fv,
    )
    self._ProcessCommandRc(fv)

  def RunWithArgs(
      self, identifier: str = '', filename: Optional[str] = None
  ) -> Optional[int]:
    """Inserts rows in a table.

    Inserts the records formatted as newline delimited JSON from file
    into the specified table. If file is not specified, reads from stdin.
    If there were any insert errors it prints the errors to stdout.

    Examples:
      bq insert dataset.table /tmp/mydata.json
      echo '{"a":1, "b":2}' | bq insert dataset.table

    Template table examples:
    Insert to dataset.table_suffix table using dataset.table table as its
    template.
      bq insert -x=_suffix dataset.table /tmp/mydata.json
    """
    if filename:
      with open(filename, 'r') as json_file:
        return self._DoInsert(
            identifier,
            json_file,
            skip_invalid_rows=self.skip_invalid_rows,
            ignore_unknown_values=self.ignore_unknown_values,
            template_suffix=self.template_suffix,
            insert_id=self.insert_id,
        )
    else:
      return self._DoInsert(
          identifier,
          sys.stdin,
          skip_invalid_rows=self.skip_invalid_rows,
          ignore_unknown_values=self.ignore_unknown_values,
          template_suffix=self.template_suffix,
          insert_id=self.insert_id,
      )

  def _DoInsert(
      self,
      identifier: str,
      json_file: TextIO,
      skip_invalid_rows: Optional[bool] = None,
      ignore_unknown_values: Optional[bool] = None,
      template_suffix: Optional[int] = None,
      insert_id: Optional[str] = None,
  ) -> int:
    """Insert the contents of the file into a table."""
    client = bq_cached_client.Client.Get()
    reference = bq_client_utils.GetReference(
        id_fallbacks=client,
        identifier=identifier,
        allow_pcnt_identifier_format=True,
    )
    bq_id_utils.typecheck(
        reference,
        (bq_id_utils.ApiClientHelper.TableReference,),
        'Must provide a table identifier for insert.',
        is_usage_error=True,
    )
    batch = []

    def Flush():
      result = client_table.insert_table_rows(
          insert_client=client.GetInsertApiClient(),
          table_dict=reference,
          inserts=batch,
          skip_invalid_rows=skip_invalid_rows,
          ignore_unknown_values=ignore_unknown_values,
          template_suffix=template_suffix,
      )
      del batch[:]
      return result, result.get('insertErrors', None)

    result = {}
    errors = None
    lineno = 1
    for line in json_file:
      try:
        unique_insert_id = None
        if insert_id is not None:
          unique_insert_id = insert_id + '_' + str(lineno)
        batch.append(
            bq_processor_utils.JsonToInsertEntry(unique_insert_id, line)
        )
        lineno += 1
      except bq_error.BigqueryClientError as e:
        raise app.UsageError('Line %d: %s' % (lineno, str(e)))
      if (
          FLAGS.max_rows_per_request
          and len(batch) == FLAGS.max_rows_per_request
      ):
        result, errors = Flush()
      if errors:
        break
    if batch and not errors:
      result, errors = Flush()

    if bq_flags.FORMAT.value in ['prettyjson', 'json']:
      bq_utils.PrintFormattedJsonObject(result)
    elif bq_flags.FORMAT.value in [None, 'sparse', 'pretty']:
      if errors:
        for entry in result['insertErrors']:
          entry_errors = entry['errors']
          sys.stdout.write('record %d errors: ' % (entry['index'],))
          for error in entry_errors:
            print(
                '\t%s: %s'
                % (
                    stringutil.ensure_str(error['reason']),
                    stringutil.ensure_str(error.get('message')),
                )
            )
    return 1 if errors else 0
